Class: Worklog::LogEntryFormatters::ConsoleFormatter

Inherits:
BaseFormatter
  • Object
show all
Defined in:
lib/log_entry_formatters.rb

Overview

Formatter for console output. It adds colors and formatting to the message. It also adds emojis for tickets, tags, urls, and projects. This formatter should be used instead of the BaseFormatter when outputting to the console.

Method Summary

Methods inherited from BaseFormatter

#format, #initialize

Constructor Details

This class inherits a constructor from Worklog::LogEntryFormatters::BaseFormatter