Class: Worklog::LogEntryFormatters::SimpleFormatter
- Inherits:
-
BaseFormatter
- Object
- BaseFormatter
- Worklog::LogEntryFormatters::SimpleFormatter
- Defined in:
- lib/log_entry_formatters.rb
Overview
Simple formatter that doesn’t add any colors or metadata to the output. This formatter should be used when the output is meant to be consumed by other tools or when the formatting is not desired.
Instance Method Summary collapse
-
#format(log_entry) ⇒ String
Format the log entry message without any metadata.
Methods inherited from BaseFormatter
Constructor Details
This class inherits a constructor from Worklog::LogEntryFormatters::BaseFormatter
Instance Method Details
#format(log_entry) ⇒ String
Format the log entry message without any metadata.
100 101 102 |
# File 'lib/log_entry_formatters.rb', line 100 def format(log_entry) replace_people_handles(log_entry, log_entry..dup) end |